package fr.unistra.sil.erp.back.repository;

import fr.unistra.sil.erp.back.model.Stock;

import java.util.List;

public interface IStocksRepository {
    /**
     * Returns the list of all stocks.
     *
     * @return the list of stocks.
     */
    List<Stock> getStocks();

    /**
     * Returns the stock entry of an item.
     *
     * @param itemId the item's ID.
     * @return the stock line.
     * @throws DatabaseResourceNotFoundException when the query fails.
     */
    Stock getStockForItem(int itemId)
            throws DatabaseResourceNotFoundException;

    /**
     * Updates the specified stock's quantity.
     *
     * @param id       the stock entry's ID.
     * @param quantity the new quantity.
     * @throws DatabaseConnectionException when the database is unreachable.
     * @throws DatabaseUpdateException     when the query fails.
     */
    void updateStock(int id, int quantity)
            throws DatabaseConnectionException, DatabaseUpdateException;
}
