package fr.unistra.sil.erp.back.repository.category;

import fr.unistra.sil.erp.back.model.Category;
import fr.unistra.sil.erp.back.repository.ICategoriesRepository;
import fr.unistra.sil.erp.back.repository.SqliteRepository;
import org.springframework.stereotype.Repository;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

@Repository
public class SqliteCategoryRepository extends SqliteRepository implements ICategoriesRepository {

    /**
     * Query used to retrieve all categories stored in the database.
     */
    private static final String SQL_GETCATEGORIES =
            "SELECT id, name FROM categories";

    public SqliteCategoryRepository(Connection conn) {
        super(conn);
    }

    @Override
    public List<Category> getCategories() {
        ResultSet rs = this.query(SQL_GETCATEGORIES);
        if (rs == null)
            return null;

        List<Category> res = new ArrayList<>();
        try {
            while (rs.next()) {
                Category c = new Category(rs.getInt("id"), rs.getString("name"));
                res.add(c);
            }
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, "Failed to fetch results.", ex);
            return null;
        }

        return res;
    }
}
