package fr.unistra.sil.erp.back.repository.item;

import fr.unistra.sil.erp.back.model.Item;
import fr.unistra.sil.erp.back.repository.IItemsRepository;
import fr.unistra.sil.erp.back.repository.SqliteRepository;
import org.springframework.stereotype.Repository;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

@Repository
public class SqliteItemsRepository extends SqliteRepository implements IItemsRepository {

    /**
     * Query used to select all items stored in the database.
     */
    private static final String SQL_GETALLITEMS =
            "SELECT ref, name, price, subscriberPrice, category FROM items";

    /**
     * Query used to get all items stored in the database from a specific
     * category.
     */
    private static final String SQL_GETITEMSFROMCATEGORY = SQL_GETALLITEMS +
            " WHERE category = ?";

    /**
     * Class constructor.
     */
    public SqliteItemsRepository(Connection conn) {
        super(conn);
    }


    @Override
    public List<Item> getAllItems() {
        ResultSet rs = query(SQL_GETALLITEMS);
        if (rs == null)
            return null;

        List<Item> res = new ArrayList<>();
        try {
            while (rs.next()) {
                Item item = new Item(rs.getInt("ref"), rs.getString("name"),
                        rs.getBigDecimal("price"),
                        rs.getBigDecimal("subscriberPrice"),
                        rs.getInt("category"));
                res.add(item);
            }
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, null, ex);
            return null;
        }

        return res;
    }

    @Override
    public List<Item> getItemsFromCategory(int category) {
        PreparedStatement ps;
        try {
            ps = this.conn.prepareStatement(
                    SQL_GETITEMSFROMCATEGORY);
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, "Failed to connect to database.", ex);
            return null;
        }

        try {
            ps.setInt(1, category);
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, "Failed to set query parameter.", ex);
            return null;
        }

        ResultSet rs;
        try {
            rs = ps.executeQuery();
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, "Failed to fetch items for category " +
                            category, ex);
            return null;
        }

        List<Item> res = new ArrayList<>();
        try {
            while (rs.next()) {
                Item item = new Item(rs.getInt("ref"), rs.getString("name"),
                        rs.getBigDecimal("price"),
                        rs.getBigDecimal("subscriberPrice"),
                        rs.getInt("category"));
                res.add(item);
            }
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, "Failed to parse results.", ex);
            return null;
        }

        return res;
    }
}
