package fr.unistra.sil.erp.back.repository.registry;

import fr.unistra.sil.erp.back.model.RegistryEntry;
import fr.unistra.sil.erp.back.repository.IRegistryRepository;
import fr.unistra.sil.erp.back.repository.SqliteRepository;
import org.springframework.stereotype.Repository;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

@Repository
public class SqliteRegistryRepository extends SqliteRepository implements IRegistryRepository {
    /**
     * Query used to retrieve the registry.
     */
    private static final String SQL_GETREGISTRY =
            "SELECT r.id AS id, r.dt AS date, r.type AS type, " +
                    "r.account_id AS account, r.debit AS debit, r.credit AS credit, " +
                    "r.remarks AS remarks FROM Registry r";

    /**
     * Class constructor.
     */
    public SqliteRegistryRepository(Connection conn) {
        super(conn);
    }

    @Override
    public List<RegistryEntry> getRegistry() {
        ResultSet rs = this.query(SQL_GETREGISTRY);
        if (rs == null)
            return null;

        List<RegistryEntry> res = new ArrayList<>();
        try {
            while (rs.next()) {
                RegistryEntry r = new RegistryEntry(rs.getInt("id"),
                        rs.getInt("type"), new Date(rs.getInt("date") * 1000L),
                        rs.getInt("account"),
                        rs.getBigDecimal("debit"), rs.getBigDecimal("credit"),
                        rs.getString("remarks"));
                res.add(r);
            }
        } catch (SQLException ex) {
            Logger.getLogger(this.getClass().getName()).log(
                    Level.SEVERE, "Failed to fetch results.", ex);
            return null;
        }

        return res;
    }
}
